@@ -9,6 +9,7 @@ from .timeline import Timeline
 class Universe:
     _id: int
     _timeline: Timeline
+    _accuracy: int
     _till: Union[int, float]
 
     def __new__(cls):
@@ -16,10 +17,11 @@ class Universe:
             cls.instance = super(Universe, cls).__new__(cls)
         return cls.instance
 
-    def __init__(self) -> None:
+    def __init__(self, accuracy:int=3) -> None:
         self._id = uuid4().int
         self._timeline = Timeline()
         self._till = int()
+        self._accuracy = accuracy
 
     def simulate(self, till: Union[int, float] = inf) -> None:
         self._till = till
@@ -39,6 +41,13 @@ class Universe:
     @property
     def now(self) -> Union[int, float]:
         return self.timeline.now
+    
+    @property
+    def accuracy(self) -> int:
+        return self._accuracy
 
+    @accuracy.setter
+    def accuracy(self, value: int) -> None:
+        self._accuracy = value
 
 Mundus = Universe()
